@@ -1,14 +1,15 @@
 use strict; use warnings;
 package Lingy::Lang::Boolean;
 
-use base 'Lingy::Lang::ScalarClass';
+use Lingy::Common;
+use base SCALARTYPE;
 
 {
     package Lingy::Common;
     my ($t, $f);
     ($t, $f) = (1, 0);
-    my $true = bless \$t, 'Lingy::Lang::Boolean';
-    my $false = bless \$f, 'Lingy::Lang::Boolean';
+    my $true = bless \$t, BOOLEAN;
+    my $false = bless \$f, BOOLEAN;
     sub true { $true }
     sub false { $false }
 }
@@ -17,8 +18,8 @@ sub new {
     my ($class, $scalar) = @_;
     my $type = ref($scalar);
     (not $type) ? $scalar ? Lingy::Common::true() : Lingy::Common::false() :
-    $type eq 'Lingy::Lang::Nil' ? Lingy::Common::false :
-    $type eq 'Lingy::Lang::Boolean' ? $scalar :
+    $type eq NIL ? Lingy::Common::false :
+    $type eq BOOLEAN ? $scalar :
     Lingy::Common::true();
 }
 
